@@ -31,7 +31,7 @@ try:
 except:  # to fix python setup error on Windows.
     pass
 
-__version__ = "0.1.29"
+__version__ = "0.1.30"
 __author__ = "Xiaocong He"
 __all__ = ["device", "Device", "rect", "point", "Selector", "JsonRPCError"]
 
@@ -833,7 +833,7 @@ class AutomatorDeviceUiObject(object):
                 else:
                     return self.jsonrpc.longClick(self.selector)
             else:
-                bounds = info["visibleBounds"]
+                bounds = info.get("visibleBounds") or info.get("bounds")
                 if corner in ["tl", "topleft"]:
                     x = (5*bounds["left"] + bounds["right"])/6
                     y = (5*bounds["top"] + bounds["bottom"])/6
